using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Text.RegularExpressions;

namespace MisnamedFilter.Configurator
{
	public partial class SimpleAdd : Form
	{
		private Main mParent;
		private SimpleAdd()
		{
			InitializeComponent();

			PopulateModeCombos();
		}
		public SimpleAdd(Main parent) : this()
		{
			mParent = parent;
			Font = parent.Font;
		}

		protected override void OnHelpButtonClicked(CancelEventArgs e)
		{
			Main.ShowHelp();
			e.Cancel = true;
		}

		private void Validate(object sender, EventArgs e)
		{
			//OK is only allowed if both address and name have text in them.
			mOK.Enabled = !String.IsNullOrEmpty(mAddress.Text) && !String.IsNullOrEmpty(mName.Text);
		}

		/// <summary>
		/// A name to use for the address set generated
		/// </summary>
		public string AddressSetName
		{
			get
			{
				return mAddress.Text;
			}
		}

		public string AddressPattern
		{
			get
			{
				return ((ModeItem)mAddressMode.SelectedItem).CreatePattern(mAddress.Text);
			}
		}

		public string NamePattern
		{
			get
			{
				return ((ModeItem)mNameMode.SelectedItem).CreatePattern(mName.Text);
			}
		}

		#region Modes
		private enum Mode
		{
			Is,
			StartsWith,
			EndsWith,
			Contains
		}
		private class ModeItem
		{
			private Mode mMode;
			public ModeItem(Mode mode)
			{
				mMode = mode;
			}
			public override string ToString()
			{
				switch (mMode)
				{
					case Mode.Is:
						return "Is";
					case Mode.StartsWith:
						return "Starts With";
					case Mode.EndsWith:
						return "Ends With";
					case Mode.Contains:
						return "Contains";
				}
				return null;
			}

			/// <summary>
			/// Creates a Regex pattern for the specified text, in this mode
			/// </summary>
			internal string CreatePattern(string text)
			{
				string escapedText = Regex.Escape(text);
				switch (mMode)
				{
					case Mode.Is:
						return String.Format("^{0}$", escapedText);
					case Mode.StartsWith:
						return String.Format("^{0}", escapedText);
					case Mode.EndsWith:
						return String.Format("{0}$", escapedText);
					case Mode.Contains:
						return escapedText;
				}
				return null;
			}
		}

		private void PopulateModeCombos()
		{
			object[] modes = new object[] { new ModeItem(Mode.Is),
											new ModeItem(Mode.StartsWith),
											new ModeItem(Mode.EndsWith),
											new ModeItem(Mode.Contains) };

			//Set the auto-width
			using (Graphics g = mAddress.CreateGraphics())
			{
				mNameMode.Width = mAddressMode.Width = SystemInformation.VerticalScrollBarWidth + 5 +//Add on space for the dropper, and a bit of a cosmetic gap
								 (int)g.MeasureString(new ModeItem(Mode.StartsWith).ToString(), mAddress.Font).Width; //Longest mode name
			}

			mAddressMode.Items.Clear();
			mAddressMode.Items.AddRange(modes);
			mAddressMode.SelectedIndex = 0;

			mNameMode.Items.Clear();
			mNameMode.Items.AddRange(modes);
			mNameMode.SelectedIndex = 0;
		}
		#endregion

		
	}
}