/* Part of Misnamed Filter (see Misnamed Filter.cpp)
 * by Alex Vallat <www.byalexv.co.uk>
 */
#include "Settings.h"

using namespace System::IO;

MisnamedFilter::Settings::Settings(void)
{
	Reload();
}
void MisnamedFilter::Settings::Reload()
{
	AddressSets = gcnew List<AddressSet^>();
	AutoLearn = true; //by default

	String^ filename = GetFileName();

	if (File::Exists(filename))
	{
		XmlDocument^ settings = gcnew XmlDocument();
		try
		{
			settings->Load(filename);
		}
		catch (Exception^ e)
		{
			System::Windows::Forms::MessageBox::Show(String::Format("Could not load settings file from:\n\n  {0}\n\n{1}", filename, e->Message), "Misnamed Filter");
			settings = nullptr;
		}

		if (settings != nullptr)
		{
			AutoLearn = XmlConvert::ToBoolean(settings->DocumentElement->GetAttribute("autoLearn"));
			for each (XmlElement^ addressSetElement in settings->DocumentElement->SelectNodes("AddressSet"))
			{
				AddressSet^ addressSet = gcnew AddressSet(addressSetElement);
				AddressSets->Add(addressSet);
			}
		}
	}
}
void MisnamedFilter::Settings::Save()
{
	XmlDocument^ settings = gcnew XmlDocument();
	settings->AppendChild(settings->CreateElement("MisnamedFilter"));
	settings->DocumentElement->SetAttribute("autoLearn", XmlConvert::ToString(AutoLearn));
	for each (AddressSet^ addressSet in AddressSets)
	{
		settings->DocumentElement->AppendChild(addressSet->Serialise(settings));
	}

	try
	{
		settings->Save(GetFileName());
	}
	catch (Exception^ e)
	{
		System::Windows::Forms::MessageBox::Show(String::Format("Could not save settings file to:\n\n  {0}\n\n{1}", GetFileName(), e->Message));
	}
}
String^ MisnamedFilter::Settings::GetSettingsFolder()
{
	String^ baseSettingsPath;
	//Check to see whether using per-user or all-users settings
	if ((int)Microsoft::Win32::Registry::GetValue("HKEY_LOCAL_MACHINE\\SOFTWARE\\Spamihilator", "ConfigDir", 1) == 0)
	{
		//0 = per-user
		baseSettingsPath = Path::Combine(Environment::GetFolderPath(Environment::SpecialFolder::ApplicationData), "Spamihilator\\plugins");
	}
	else
	{
		//1 = all-users
		baseSettingsPath = Path::GetDirectoryName(Settings::typeid->Assembly->Location);
	}

#if FORCE_LOCAL_SETTIGS_FILE
	baseSettingsPath = Path::GetDirectoryName(Settings::typeid->Assembly->Location);
#endif

	return Path::Combine(baseSettingsPath, "Misnamed Filter");
}
String^ MisnamedFilter::Settings::GetFileName()
{
	return Path::Combine(GetSettingsFolder(),"Misnamed Filter.settings.xml");
}